summaryrefslogtreecommitdiff
path: root/misc
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2002-02-22 17:12:15 +0000
committerjbj <devnull@localhost>2002-02-22 17:12:15 +0000
commit0108a7b8cbcfeb1ed6a97e8841d234616e91de5b (patch)
tree022199fc3d60b537829c4370aab04001d1934d11 /misc
parent66477dc13d82817781de9e3d08db5d1d052ebf28 (diff)
downloadlibrpm-tizen-0108a7b8cbcfeb1ed6a97e8841d234616e91de5b.tar.gz
librpm-tizen-0108a7b8cbcfeb1ed6a97e8841d234616e91de5b.tar.bz2
librpm-tizen-0108a7b8cbcfeb1ed6a97e8841d234616e91de5b.zip
tpkgid cleanup.
Recognize GNU extensions in myGlobPatternP(), flag in misc/fnmatch.h, as well. CVS patchset: 5331 CVS date: 2002/02/22 17:12:15
Diffstat (limited to 'misc')
-rw-r--r--misc/fnmatch.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/misc/fnmatch.h b/misc/fnmatch.h
index eeaee7fb8..c0fd6a920 100644
--- a/misc/fnmatch.h
+++ b/misc/fnmatch.h
@@ -1,20 +1,20 @@
-/* Copyright (C) 1991, 92, 93, 96, 97, 98 Free Software Foundation, Inc.
+/* Copyright (C) 1991,92,93,96,97,98,99,2001 Free Software Foundation, Inc.
This file is part of the GNU C Library.
The GNU C Library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public License as
- published by the Free Software Foundation; either version 2 of the
- License, or (at your option) any later version.
+ modify it under the terms of the GNU Lesser General Public
+ License as published by the Free Software Foundation; either
+ version 2.1 of the License, or (at your option) any later version.
The GNU C Library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- Library General Public License for more details.
+ Lesser General Public License for more details.
- You should have received a copy of the GNU Library General Public
- License along with the GNU C Library; see the file COPYING.LIB. If not,
- write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- Boston, MA 02111-1307, USA. */
+ You should have received a copy of the GNU Lesser General Public
+ License along with the GNU C Library; if not, write to the Free
+ Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+ 02111-1307 USA. */
#ifndef _FNMATCH_H
#define _FNMATCH_H 1
@@ -59,6 +59,7 @@ extern "C" {
# define FNM_FILE_NAME FNM_PATHNAME /* Preferred GNU name. */
# define FNM_LEADING_DIR (1 << 3) /* Ignore `/...' after a match. */
# define FNM_CASEFOLD (1 << 4) /* Compare without regard to case. */
+# define FNM_EXTMATCH (1 << 5) /* Use ksh-like extended matching. */
#endif
/* Value returned by `fnmatch' if STRING does not match PATTERN. */
@@ -72,9 +73,9 @@ extern "C" {
# define FNM_NOSYS (-1)
#endif
/* Match STRING against the filename pattern PATTERN,
returning zero if it matches, FNM_NOMATCH if not. */
-extern int fnmatch __P ((__const char *__pattern, __const char *__string,
+extern int fnmatch __P ((__const char *__pattern, __const char *__name,
int __flags));
#ifdef __cplusplus
@@ -72,9 +73,9 @@ extern "C" {
# define FNM_NOSYS (-1)
#endif
-/* Match STRING against the filename pattern PATTERN,
+/* Match NAME against the filename pattern PATTERN,
returning zero if it matches, FNM_NOMATCH if not. */